@@ -39,6 +39,7 @@ from nuvo_serial.message import (
     format_message,
     process_message,
     OKResponse,
+    Mute,
     Paging,
     Party,
     SourceConfiguration,
@@ -370,6 +371,24 @@ class AsyncConnection:
     ) -> Union[ZoneButton, ZoneStatus, OKResponse]:
         ...
 
+    @overload
+    async def send_message(
+        self,
+        msg: str,
+        message_types: Tuple[
+            Literal["ZoneStatus"], Literal["Mute"]
+        ],
+    ) -> Union[ZoneStatus, Mute]:
+        ...
+
+    @overload
+    async def send_message(self, msg: str, message_types: Literal["OKResponse"],) -> OKResponse:
+        ...
+
+    @overload
+    async def send_message(self, msg: str, message_types: Literal["Mute"],) -> Mute:
+        ...
+
     @overload
     async def send_message(self, msg: str, message_types: Literal["Paging"],) -> Paging:
         ...
@@ -657,12 +676,6 @@ class AsyncConnection:
             else:
                 # There message has been classified but it may not be the wanted
                 # message_type
-                if processed_type == ERROR_RESPONSE:
-                    err_msg = (
-                        "Message produced an error response from the Nuvo controller"
-                    )
-                    _LOGGER.debug("RESPONSEREADER: MessageResponseError: %s", err_msg)
-                    raise MessageResponseError(err_msg)
                 if processed_type in message_types:
                     _LOGGER.debug(
                         "RESPONSEREADER: Found matching response: %s", d_class
@@ -670,6 +683,12 @@ class AsyncConnection:
                     found_match = True
                     match = (processed_type, d_class)
                     break
+                elif processed_type == ERROR_RESPONSE:
+                    err_msg = (
+                        "Message produced an error response from the Nuvo controller"
+                    )
+                    _LOGGER.debug("RESPONSEREADER: MessageResponseError: %s", err_msg)
+                    raise MessageResponseError(err_msg)
                 else:
                     # The message has been classified but it's not the wanted
                     # message_type
@@ -688,7 +707,7 @@ class AsyncConnection:
         """
         message = await self._reader.readuntil(self._eol)
         # We have bytes with the correct eol chars but is it in the correct format?
-        if re.match(b"#.+?" + self._eol, message):
+        if re.match(b"(\x00\x00)?#.+?" + self._eol, message):
             return message
         else:
             raise MessageFormatError(message)
