@@ -7,8 +7,10 @@ ERROR_RESPONSE: Final = "ErrorResponse"
 OK_RESPONSE: Final = "OKResponse"
 SOURCE_CONFIGURATION: Final = "SourceConfiguration"
 SYSTEM_VERSION: Final = "Version"
+SYSTEM_MUTE: Final = "Mute"
 SYSTEM_PAGING: Final = "Paging"
 SYSTEM_PARTY: Final = "Party"
+SYSTEM_RESTART: Final = "Restart"
 ZONE_STATUS: Final = "ZoneStatus"
 ZONE_CONFIGURATION: Final = "ZoneConfiguration"
 ZONE_VOLUME_CONFIGURATION: Final = "ZoneVolumeConfiguration"
