@@ -4,6 +4,7 @@ import asyncio
 from collections.abc import Coroutine
 from copy import deepcopy
 from dataclasses import asdict, replace
+from datetime import datetime
 import logging
 from typing import Any, Callable, Iterable, Optional, Union, List, Set
 
@@ -24,6 +25,7 @@ from nuvo_serial.const import (
     EMIT_LEVEL_EXTERNAL,
     EMIT_LEVEL_INTERNAL,
     EMIT_LEVEL_NONE,
+    ERROR_RESPONSE,
     ZONE_ALL_OFF,
     ZONE_STATUS,
     ZONE_EQ_STATUS,
@@ -34,6 +36,7 @@ from nuvo_serial.const import (
     ZONE_BUTTON_PLAY_PAUSE,
     ZONE_BUTTON_PREV,
     ZONE_BUTTON_NEXT,
+    SYSTEM_MUTE,
     SYSTEM_PAGING,
     SYSTEM_PARTY,
     SYSTEM_VERSION,
@@ -42,7 +45,9 @@ from nuvo_serial.const import (
 from nuvo_serial.exceptions import ModelMismatchError
 from nuvo_serial.message import (
     DndMask,
+    ErrorResponse,
     OKResponse,
+    Mute,
     Paging,
     Party,
     SourceConfiguration,
@@ -763,31 +768,31 @@ class NuvoAsync:
 
     @locked
     @icontract.require(lambda zone: zone in ZONE_RANGE)
-    async def set_mute(self, zone: int, mute: bool) -> ZoneStatus:
+    async def set_mute(self, zone: int, mute: bool) -> ZoneStatus | Mute:
         return await self._connection.send_message(
-            _format_set_mute(zone, mute), ZONE_STATUS
+            _format_set_mute(zone, mute), (ZONE_STATUS, SYSTEM_MUTE)
         )
 
     @locked
     @icontract.require(lambda zone: zone in ZONE_RANGE)
     @icontract.require(lambda volume: volume in VOLUME_RANGE)
-    async def set_volume(self, zone: int, volume: int) -> ZoneStatus:
+    async def set_volume(self, zone: int, volume: int) -> ZoneStatus | Mute:
         return await self._connection.send_message(
-            _format_set_volume(zone, volume), ZONE_STATUS
+            _format_set_volume(zone, volume), (ZONE_STATUS, SYSTEM_MUTE)
         )
 
     @locked
     @icontract.require(lambda zone: zone in ZONE_RANGE)
-    async def volume_up(self, zone: int) -> ZoneStatus:
+    async def volume_up(self, zone: int) -> ZoneStatus | Mute:
         return await self._connection.send_message(
-            _format_volume_up(zone), ZONE_STATUS
+            _format_volume_up(zone), (ZONE_STATUS, SYSTEM_MUTE)
         )
 
     @locked
     @icontract.require(lambda zone: zone in ZONE_RANGE)
-    async def volume_down(self, zone: int) -> ZoneStatus:
+    async def volume_down(self, zone: int) -> ZoneStatus | Mute:
         return await self._connection.send_message(
-            _format_volume_down(zone), ZONE_STATUS
+            _format_volume_down(zone), (ZONE_STATUS, SYSTEM_MUTE)
         )
 
     @locked
@@ -815,10 +820,11 @@ class NuvoAsync:
         )
 
     async def restore_zone(self, status: ZoneStatus) -> ZoneStatus:
-        await self.set_power(status.zone, status.power)
-        await self.set_mute(status.zone, status.mute)
-        await self.set_volume(status.zone, status.volume)
-        z_status: ZoneStatus = await self.set_source(status.zone, status.source)
+        z_status = await self.set_power(status.zone, status.power)
+        if status.power:
+            await self.set_mute(status.zone, status.mute)
+            await self.set_volume(status.zone, status.volume)
+            z_status: ZoneStatus = await self.set_source(status.zone, status.source)
         return z_status
 
     """
@@ -1139,8 +1145,8 @@ class NuvoAsync:
         )
 
     @locked
-    async def all_off(self) -> ZoneAllOff:
-        return await self._connection.send_message("ALLOFF", ZONE_ALL_OFF)
+    async def all_off(self) -> ZoneAllOff | ErrorResponse:
+        return await self._connection.send_message("ALLOFF", (ZONE_ALL_OFF, ERROR_RESPONSE))
 
     @locked
     async def get_version(self) -> Version:
@@ -1153,6 +1159,20 @@ class NuvoAsync:
             _format_set_party_host(zone, enable), SYSTEM_PARTY
         )
 
+    @locked
+    async def configure_time(self, date_time: datetime) -> OKResponse:
+        return await self._connection.send_message(
+            _format_configure_time(date_time), OK_RESPONSE
+
+        )
+
+    @locked
+    async def mute_all_zones(self, mute: bool) -> Mute:
+        return await self._connection.send_message(
+            _format_mute_all_zones(mute), SYSTEM_MUTE
+
+        )
+
 
 class NuvoSync:
     def __init__(self, port_url: str, model: str, retries: Optional[int] = None):
@@ -1248,10 +1268,11 @@ class NuvoSync:
     @synchronized
     def restore_zone(self, status: ZoneStatus) -> Optional[ZoneStatus]:
         rtn: Optional[ZoneStatus]
-        self.set_power(status.zone, status.power)  # ZoneStatus
-        self.set_mute(status.zone, status.mute)  # ZoneStatus
-        self.set_volume(status.zone, status.volume)  # ZoneStatus
-        rtn = self.set_source(status.zone, status.source)  # ZoneStatus
+        rtn = self.set_power(status.zone, status.power)  # ZoneStatus
+        if status.power:
+            self.set_mute(status.zone, status.mute)  # ZoneStatus
+            self.set_volume(status.zone, status.volume)  # ZoneStatus
+            rtn = self.set_source(status.zone, status.source)  # ZoneStatus
         return rtn
 
     """
@@ -1613,6 +1634,19 @@ class NuvoSync:
         )
         return rtn
 
+    @synchronized
+    def configure_time(self, date_time: datetime) -> Optional[OKResponse]:
+        rtn: Optional[OKResponse]
+        rtn = self._retry_request(
+            _format_configure_time(date_time), "Configure Time", OKResponse)
+        return rtn
+
+    @synchronized
+    def mute_all_zones(self, mute: bool) -> Optional[Mute]:
+        rtn: Optional[Mute]
+        rtn = self._retry_request(
+            _format_mute_all_zones(mute), "Mute All Zones", Mute)
+        return rtn
 
 def _is_int(s: Union[int, float, str]) -> bool:
     try:
@@ -1635,6 +1669,14 @@ def _format_set_party_host(zone: int, enable: bool) -> str:
     return "Z{}PARTY{}".format(zone, int(enable))
 
 
+def _format_configure_time(date_time: datetime) -> str:
+    return "CFGTIME{}".format(date_time.strftime('%Y,%m,%d,%H,%M'))
+
+
+def _format_mute_all_zones(mute: bool) -> str:
+    return "MUTE{}".format(int(mute))
+
+
 """
 Zone EQ Formats
 """
